@@ -68,7 +68,7 @@ test_that("tests with mock", {
     ))
 
     if (backends[[i]] == "database") {
-      CDMConnector::cdm_disconnect(cdm)
+      CDMConnector::cdmDisconnect(cdm)
     }
   }
 })
